package com.atguigu.spzx.manger.service.impl;

import com.atguigu.constant.MessageConstant;
import com.atguigu.exception.BunnyException;
import com.atguigu.spzx.manger.mapper.SysMenuMapper;
import com.atguigu.spzx.manger.service.SysMenuService;
import com.atguigu.spzx.model.entity.system.SysMenu;
import com.atguigu.utils.MenuHelper;
import com.atguigu.utils.StringEmptyUtil;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.List;

@Service
public class SysMenuServiceImpl implements SysMenuService {
    @Autowired
    private SysMenuMapper sysMenuMapper;
    @Autowired
    private StringEmptyUtil emptyUtil;

    /**
     * 查询菜单
     *
     * @return 菜单列表
     */
    @Override
    public List<SysMenu> findNodes() {
        List<SysMenu> sysMenuList = sysMenuMapper.selectAll();
        return MenuHelper.buildTree(sysMenuList);
    }

    /**
     * 添加菜单
     *
     * @param sysMenu 系统菜单实体类
     */
    @Override
    public void save(SysMenu sysMenu) {
        sysMenuMapper.insert(sysMenu);
    }

    /**
     * 修改菜单
     *
     * @param sysMenu 系统菜单实体类
     */
    @Override
    public void updateById(SysMenu sysMenu) {
        emptyUtil.isEmpty(sysMenu.getId(), MessageConstant.DELETE_ID_IS_NOT_EMPTY);
        sysMenuMapper.updateById(sysMenu);
    }

    /**
     * 删除菜单
     *
     * @param id 菜单id
     */
    @Override
    public void removeById(Long id) {
        int count = sysMenuMapper.countByParentId(id);  // 先查询是否存在子菜单，如果存在不允许进行删除
        if (count > 0) {
            throw new BunnyException(MessageConstant.MENU_IS_NOT_EXIST);
        }
        sysMenuMapper.deleteById(id);
    }
}
